@@ -71,7 +71,6 @@ typedef struct pw_auth_hdr {
 #define RT_ASCEND_RELEASE_IP            52
 
 
-#define DV_ACCT_STATUS_TYPE_QUERY       -1
 
 /* Basic structures */
 
@@ -99,6 +98,8 @@ enum {
 #define AP_ADD_NONE      2
 
 #define AP_PROPAGATE   0x10
+#define AP_REQ_CMP     0x20
+#define AP_USER_FLAG(n) (0x1000<<(n))
 
 #define ADDITIVITY(val) ((val) & 0x3)
 #define SET_ADDITIVITY(val,a) ((val) = ((val) & ~0x3) | (a))
@@ -261,7 +262,9 @@ VALUE_PAIR *avp_alloc();
 void avp_free();
 void avl_free(VALUE_PAIR *);
 VALUE_PAIR *avl_find(VALUE_PAIR *, int);
+VALUE_PAIR *avl_find_n(VALUE_PAIR *, int, int);
 void avl_delete(VALUE_PAIR **, int);
+void avl_delete_n(VALUE_PAIR **first, int attr, int n);
 void avl_add_list(VALUE_PAIR **, VALUE_PAIR *);
 void avl_add_pair(VALUE_PAIR **, VALUE_PAIR *);
 VALUE_PAIR *avl_dup(VALUE_PAIR *from);
@@ -271,6 +274,8 @@ VALUE_PAIR *avp_create(int attr, int length, char *strval, int lval);
 void avl_move_attr(VALUE_PAIR **to, VALUE_PAIR **from, int attr);
 void avl_move_pairs(VALUE_PAIR **to, VALUE_PAIR **from,
 		    int (*fun)(), void *closure);
+int avl_cmp(VALUE_PAIR *a, VALUE_PAIR *b, int prop);
+int avp_cmp(VALUE_PAIR *a, VALUE_PAIR *b);
 
 extern int do_not_resolve;
 char *ip_hostname (UINT4);
@@ -307,7 +312,7 @@ void radpath_init();
 /* users.y */
 int parse_file(char *file, void *c, int (*f)());
 int user_gettime(char *valstr, struct tm *tm);
-VALUE_PAIR *install_pair(char *name, int op, char *valstr);
+VALUE_PAIR *install_pair0(char *file, int line, char *name, int op, char *valstr);
 
 
 /* util.c */
