@@ -201,6 +201,7 @@ void snmp_req_drop(int type, SNMP_REQ *req, char *status_str);
 #define AUTH_FAIL    1 /* Password fail */
 #define AUTH_NOUSER  2 /* No such user  */
 #define AUTH_REJECT  3 /* Rejected */
+#define AUTH_IGNORE  4 /* Ignored */
 
 /* Logging modes */
 #define RLOG_AUTH               0x0001
@@ -238,6 +239,7 @@ extern UINT4 expiration_seconds;
 extern UINT4 warning_seconds;
 extern int radius_pid;
 extern int use_dbm;
+extern int ace_client_ip;
 extern UINT4 myip;
 extern UINT4 warning_seconds;
 extern int auth_port;
@@ -249,6 +251,8 @@ extern char *message_text[MSG_COUNT];
 extern char *username_valid_chars;
 extern unsigned long stat_start_time;
 extern REQUEST_CLASS    request_class[];
+extern int auth_comp_flag; /* ... authentication requests */
+extern int acct_comp_flag; /* ... accounting requests */
 
 #ifdef USE_SNMP
 extern int snmp_port;
@@ -321,6 +325,12 @@ int pam_pass(char *name, char *passwd, const char *pamauth, char **reply_msg);
 # define PAM_DEFAULT_TYPE    "radius"
 #endif
 
+/* securid.c */
+#ifdef USE_SECURID
+int securid_pass(char *name, char *passcode, char **reply_msg,
+		 RADIUS_REQ *radreq);
+#endif
+
 /* proxy.c */
 int rad_proxy(RADIUS_REQ *radreq, int activefd);
 void rad_proxy_free(RADIUS_REQ *req);
