@@ -18,7 +18,7 @@
 #define RADIUS_MODULE_AUTH_C
 #ifndef lint
 static char rcsid[] =
-"@(#) $Id: auth.c,v 1.47.2.2 2002/05/30 14:06:41 gray Exp $";
+"@(#) $Id: auth.c,v 1.47.2.8 2002/08/17 09:10:22 gray Exp $";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -198,7 +198,7 @@ unix_pass(name, passwd)
 	 * Forbid logins on passwordless accounts 
 	 */
 	if (encrypted_pass[0] == 0)
-		return 0;
+		return -1;
 
 	/*
 	 * Check encrypted password.
@@ -218,7 +218,7 @@ unix_pass(name, passwd)
  *			AUTH_FAIL    Password fail
  *                      AUTH_NOUSER  No such user 
  *			AUTH_REJECT  Rejected
- *			
+ *			AUTH_IGNORE  Silently Ignored
  */
 int
 rad_check_password(radreq, check_item, namepair, user_msg, userpass)
@@ -239,6 +239,10 @@ rad_check_password(radreq, check_item, namepair, user_msg, userpass)
 	int result;
 	char *authdata = NULL;
 	char pw_digest[AUTH_VECTOR_LEN];
+        int pwlen;
+        char *pwbuf;
+        char *challenge;
+	int challenge_len;
 	
 	result = AUTH_OK;
 	userpass[0] = 0;
@@ -247,12 +251,17 @@ rad_check_password(radreq, check_item, namepair, user_msg, userpass)
 	if ((tmp = avl_find(check_item, DA_AUTH_TYPE)) != NULL)
 		auth_type = tmp->lvalue;
 
-	if (auth_type == DV_AUTH_TYPE_ACCEPT)
+	switch (auth_type) {
+	case DV_AUTH_TYPE_ACCEPT:
 		return AUTH_OK;
 
-	if (auth_type == DV_AUTH_TYPE_REJECT) 
+	case DV_AUTH_TYPE_REJECT:
 		return AUTH_REJECT;
 
+	case DV_AUTH_TYPE_IGNORE:
+		return AUTH_IGNORE;
+	}
+
 	/* Find the password sent by the user. If it's not present,
 	   authentication fails. */
 	
@@ -335,6 +344,19 @@ rad_check_password(radreq, check_item, namepair, user_msg, userpass)
 #endif
 		break;
 
+	case DV_AUTH_TYPE_SECURID:
+#ifdef USE_SECURID
+		debug(1, ("  auth: SecurID"));
+		if (securid_pass(name, userpass, user_msg, radreq) != 0)
+			result = AUTH_FAIL;
+#else
+		radlog(L_ERR,
+		       _("%s: SecurID authentication not available"),
+		       name);
+		result = AUTH_NOUSER;
+#endif
+		break;
+
 	case DV_AUTH_TYPE_CRYPT_LOCAL:
 		debug(1, ("  auth: Crypt"));
 		if (real_password == NULL) {
@@ -369,33 +391,39 @@ rad_check_password(radreq, check_item, namepair, user_msg, userpass)
 			result = AUTH_FAIL;
 			break;
 		}
-		i = 0;
-		ptr = userpass;
-		*ptr++ = *auth_item->strvalue;
-		i++;
-		length = strlen(real_password);
-		memcpy(ptr, real_password, length);
-		ptr += length;
-		i += length;
+		/* Compute the length of the password buffer and
+		   allocate it */
+                length = strlen(real_password);
 		
-		/* Use Chap-Challenge pair if present,
-		   Request-Authenticator otherwise. */
-		if (tmp = avl_find(radreq->request, DA_CHAP_CHALLENGE)) {
-			memcpy(ptr, tmp->strvalue, tmp->strlength);
-			i += tmp->strlength;
-		} else {
-			memcpy(ptr, radreq->vector, AUTH_VECTOR_LEN);
-			i += AUTH_VECTOR_LEN;
-		}
-		md5_calc(pw_digest, (u_char*) userpass, i);
+                if (tmp = avl_find(radreq->request, DA_CHAP_CHALLENGE)) {
+                        challenge = tmp->strvalue;
+                        challenge_len = tmp->strlength;
+                } else {
+                        challenge = radreq->vector;
+                        challenge_len = AUTH_VECTOR_LEN;
+                }
+
+                pwlen = 1 + length + challenge_len;
+		pwbuf = emalloc(pwlen);
 		
-		/* Compare them */
-		if (memcmp(pw_digest, auth_item->strvalue + 1,
+                ptr = pwbuf;
+                *ptr++ = *auth_item->strvalue;
+                memcpy(ptr, real_password, length);
+                ptr += length;
+                memcpy(ptr, challenge, challenge_len);
+
+		/* Compute the MD5 hash */
+                md5_calc(pw_digest, (u_char*) pwbuf, pwlen);
+                efree(pwbuf);
+		
+                /* Compare them */
+                if (memcmp(pw_digest, auth_item->strvalue + 1,
 			   CHAP_VALUE_LENGTH) != 0)
-			result = AUTH_FAIL;
-		else
-			strcpy(userpass, real_password);
-		break;
+                        result = AUTH_FAIL;
+                else
+                        strcpy(userpass, real_password);
+                break;
+
 	default:
 		result = AUTH_FAIL;
 		break;
@@ -457,10 +485,14 @@ rad_auth_init(radreq, activefd)
 	 * See if the user has access to this huntgroup.
 	 */
 	if (!huntgroup_access(radreq)) {
+		VALUE_PAIR *reply = NULL;
+
 		radlog(L_NOTICE, _("No huntgroup access: [%s] (from nas %s)"),
 			namepair->strvalue, nas_request_to_name(radreq));
+	        avl_move_attr(&reply, &radreq->request, DA_PROXY_STATE);
 		rad_send_reply(RT_AUTHENTICATION_REJECT, radreq,
-			       radreq->request, NULL, activefd);
+			       reply, NULL, activefd);
+		avl_free(reply);
 		return -1;
 	}
 
@@ -857,8 +889,7 @@ sfn_init(m)
 		/* Send reject packet with proxy-pairs as a reply */
 		newstate(as_reject);
 		avl_free(m->user_reply);
-		m->user_reply = m->proxy_pairs;
-		m->proxy_pairs = NULL;
+		m->user_reply = NULL;
 	}
 }
 
@@ -938,56 +969,57 @@ sfn_validate(m)
 	RADIUS_REQ *radreq = m->req;
 	int rc;
 	
-	/*
-	 * Validate the user
-	 */
-	if ((rc = check_expiration(m)) >= 0) {
-		rc = rad_check_password(radreq,
-					m->user_check, m->namepair,
-					&m->user_msg,
-					m->userpass);
-
-		if (rc != AUTH_OK) { 
-			stat_inc(auth, radreq->ipaddr, num_rejects);
-			newstate(as_reject);
-			auth_format_msg(m, MSG_ACCESS_DENIED);
-
-			if (is_log_mode(m, RLOG_AUTH)) {
-				switch (rc) {
-				case AUTH_REJECT:
-					auth_log(m, _("Rejected"),
-						 NULL, NULL, NULL);  
-					return;
-				
-				case AUTH_NOUSER:
-					auth_log(m, _("Invalid user"),
-						 NULL, NULL, NULL);
-					return;
-				
-				case AUTH_FAIL:
-					break;
-				}
-			}
-		}		
-              /*if (p = avl_find(m->user_reply, DA_REPLY_MESSAGE))
-			m->user_msg = dup_string(p->strvalue);*/
-	}
-
-	avl_move_attr(&m->user_reply, &m->proxy_pairs, DA_PROXY_STATE);
-
+	rc = rad_check_password(radreq,
+				m->user_check, m->namepair,
+				&m->user_msg,
+				m->userpass);
 	if (rc != AUTH_OK) {
-		/*
-		 * Failed to validate the user.
-		 */
-		newstate(as_reject);
+		stat_inc(auth, radreq->ipaddr, num_rejects);
+
 		if (is_log_mode(m, RLOG_AUTH)) {
-			auth_log(m,
-				 _("Login incorrect"),
-				 is_log_mode(m, RLOG_FAILED_PASS) ?
-				                       m->userpass : NULL,
-				 NULL, NULL);
+			switch (rc) {
+			case AUTH_IGNORE:
+				auth_log(m, _("Ignored"),
+					 NULL, NULL, NULL);
+				newstate(as_stop);
+				return;
+				
+			case AUTH_REJECT:
+				auth_log(m, _("Rejected"),
+					 NULL, NULL, NULL);  
+				break;
+				
+			case AUTH_NOUSER:
+				auth_log(m, _("Invalid user"),
+					 NULL, NULL, NULL);
+				break;
+				
+			case AUTH_FAIL:
+				auth_log(m,
+					 _("Login incorrect"),
+					 is_log_mode(m, RLOG_FAILED_PASS) ?
+					 m->userpass : NULL,
+					 NULL, NULL);
+				break;
+
+			default:
+				insist_fail("sfn_validate");
+			}
 		}
+		newstate(as_reject);
+		auth_format_msg(m, MSG_ACCESS_DENIED);
 	}
+
+	if (check_expiration(m) != AUTH_OK) {
+                newstate(as_reject);
+                if (is_log_mode(m, RLOG_AUTH)) {
+                        auth_log(m,
+                                 _("Login incorrect"),
+                                 is_log_mode(m, RLOG_FAILED_PASS) ?
+				 m->userpass : NULL,
+                                 _("Password expired"), "");
+                }
+        }
 }
 
 void
@@ -1240,6 +1272,7 @@ sfn_ack(m)
 	
 	stat_inc(auth, m->req->ipaddr, num_accepts);
 
+	avl_move_attr(&m->user_reply, &m->proxy_pairs, DA_PROXY_STATE);
 	rad_send_reply(RT_AUTHENTICATION_ACK,
 		       m->req,
 		       m->user_reply,
@@ -1264,6 +1297,7 @@ sfn_reject(m)
 	AUTH_MACH *m;
 {
 	debug(1, ("REJECT: %s", m->namepair->strvalue));
+	avl_move_attr(&m->user_reply, &m->proxy_pairs, DA_PROXY_STATE);
 	rad_send_reply(RT_AUTHENTICATION_REJECT,
 		       m->req,
 		       m->user_reply,
