@@ -1,5 +1,5 @@
 /* C code produced by gperf version 2.7.2 */
-/* Command-line: /usr/local/bin/gperf -k'1,2,6,7,11,13,$' -t /home/gray/radius-0.96/radiusd/./config.kw  */
+/* Command-line: /usr/local/bin/gperf -k'1,2,6,7,11,13,$' -t /home/gray/radius-0.96-series/radiusd/./config.kw  */
 /* This file is part of GNU RADIUS.
    Copyright (C) 2000,2001, Sergey Poznyakoff
   
@@ -31,12 +31,12 @@ struct conf_tok {
 	YYSTYPE lval;
 };
 
-#define TOTAL_KEYWORDS 88
+#define TOTAL_KEYWORDS 90
 #define MIN_WORD_LENGTH 2
 #define MAX_WORD_LENGTH 23
 #define MIN_HASH_VALUE 2
-#define MAX_HASH_VALUE 252
-/* maximum key range = 251, duplicates = 0 */
+#define MAX_HASH_VALUE 324
+/* maximum key range = 323, duplicates = 0 */
 
 #ifdef __GNUC__
 __inline
@@ -50,34 +50,34 @@ hash (str, len)
      register const char *str;
      register unsigned int len;
 {
-  static unsigned char asso_values[] =
+  static unsigned short asso_values[] =
     {
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253,   0, 253, 253,  55,  10,
-       60,  20,  50,  30,  35,  45, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253,   5, 253,  80,
-       20,   0,  10,  15,  95,   0, 253,   0,  35,  10,
-      100,   0,  30,   0,   0,   0,  10,  25,  15,   5,
-        0,  55, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253, 253, 253, 253, 253,
-      253, 253, 253, 253, 253, 253
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325,   0, 325, 325,   5,  10,
+       15,  25,  30,  35,  50,  45, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325,   5, 325,  72,
+       20,   0,  10,  15, 100,   0, 325,   0,  35,  60,
+      100,   0,  40,   0,   0,   0,  12,  75,   0,   5,
+       55,  40, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325, 325, 325, 325, 325,
+      325, 325, 325, 325, 325, 325
     };
   register int hval = len;
 
@@ -132,140 +132,148 @@ in_word_set (str, len)
       {"realm-quota", T_MESGDEF, _Y(MSG_REALM_QUOTA)},
       {""},
       {"off", T_BOOL, _Y(0)},
-      {""}, {""}, {""}, {""}, {""},
+      {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
+      {""}, {""}, {""},
+      {"time-to-live", T_TTL},
+      {"ident", T_IDENT},
+      {""}, {""},
+      {"debug", T_SEVERITY, _Y(L_DEBUG)},
+      {""},
+      {"log-dir", T_LOG_DIR},
+      {"yes", T_BOOL, _Y(1)},
+      {""},
+      {"retry", T_RETRY},
+      {""}, {""}, {""},
+      {"source-ip", T_SOURCE_IP},
+      {"allow", T_ALLOW,},
+      {"local0", T_FACILITY, _Y(LOG_LOCAL0)},
+      {""},
+      {"log", T_LOGGING},
+      {""}, {""},
+      {"port", T_PORT},
+      {"alert", T_SEVERITY, _Y(L_ALERT)},
+      {""},
+      {"load", T_LOAD,},
+      {""},
+      {"local1", T_FACILITY, _Y(LOG_LOCAL1)},
+      {""}, {""},
+      {"deny", T_DENY,},
+      {"delay", T_DELAY },
+      {""},
+      {"print-failed-pass", T_LOGLEVEL, _Y(RLOG_FAILED_PASS)},
+      {""}, {""}, {""},
+      {"local2", T_FACILITY, _Y(LOG_LOCAL2)},
+      {""}, {""}, {""},
+      {"level", T_LEVEL,},
+      {"syslog", T_SYSLOG},
+      {""}, {""},
       {"user", T_FACILITY, _Y(LOG_USER)},
       {"emerg", T_SEVERITY, _Y(L_EMERG),},
       {""},
       {"message", T_MESSAGE},
       {""}, {""},
-      {"ident", T_IDENT},
-      {""},
-      {"max-requests", T_MAX_REQUESTS},
-      {""},
-      {"source-ip", T_SOURCE_IP},
-      {"debug", T_SEVERITY, _Y(L_DEBUG)},
-      {""},
-      {"log-dir", T_LOG_DIR},
-      {""},
-      {"port", T_PORT},
-      {"guile", T_GUILE,},
-      {""},
-      {"time-to-live", T_TTL},
-      {""}, {""},
-      {"allow", T_ALLOW,},
-      {"usedbm", T_USEDBM},
-      {"exec-program-user", T_EXEC_PROGRAM_USER},
-      {"log", T_LOGGING},
-      {""},
-      {"alert", T_SEVERITY, _Y(L_ALERT)},
-      {""},
-      {"print-failed-pass", T_LOGLEVEL, _Y(RLOG_FAILED_PASS)},
-      {"yes", T_BOOL, _Y(1)},
-      {"load", T_LOAD,},
-      {"retry", T_RETRY},
-      {"local1", T_FACILITY, _Y(LOG_LOCAL1)},
-      {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
-      {"print-pass", T_LOGLEVEL, _Y(RLOG_AUTH_PASS)},
-      {"password-expired", T_MESGDEF, _Y(MSG_PASSWORD_EXPIRED)},
-      {""},
-      {"password-expire-warning", T_EXPWARNING},
-      {""},
-      {"level", T_LEVEL,},
-      {""}, {""}, {""},
-      {"deny", T_DENY,},
-      {"delay", T_DELAY },
-      {"local3", T_FACILITY, _Y(LOG_LOCAL3)},
-      {""},
-      {"exec-program-group", T_EXEC_PROGRAM_GROUP},
-      {""}, {""}, {""}, {""}, {""},
-      {"print-pid", T_LOGOPT, _Y(LO_PID)},
       {"proxy", T_PROXY},
-      {"syslog", T_SYSLOG},
       {""}, {""},
       {"crit", T_SEVERITY, _Y(L_CRIT)},
+      {"max-requests", T_MAX_REQUESTS},
+      {"print-pass", T_LOGLEVEL, _Y(RLOG_AUTH_PASS)},
+      {"local3", T_FACILITY, _Y(LOG_LOCAL3)},
       {""},
-      {"detail", T_DETAIL},
-      {""}, {""},
       {"acct", T_ACCT},
       {""},
-      {"local5", T_FACILITY, _Y(LOG_LOCAL5)},
+      {"guile", T_GUILE,},
+      {"detail", T_DETAIL},
+      {""}, {""}, {""}, {""},
+      {"local4", T_FACILITY, _Y(LOG_LOCAL4)},
       {"no", T_BOOL, _Y(0),},
       {""},
       {"info", T_SEVERITY, _Y(L_INFO),},
-      {""},
+      {"acct-dir", T_ACCT_DIR},
       {"notice", T_SEVERITY, _Y(L_NOTICE)},
       {"network", T_NETWORK,},
       {""},
+      {"print-pid", T_LOGOPT, _Y(LO_PID)},
+      {""},
+      {"local5", T_FACILITY, _Y(LOG_LOCAL5)},
+      {""}, {""}, {""},
+      {"acl", T_ACL},
       {"host", T_HOST},
-      {""},
-      {"local6", T_FACILITY, _Y(LOG_LOCAL6)},
-      {""},
-      {"acct-dir", T_ACCT_DIR},
-      {""}, {""}, {""}, {""}, {""},
-      {"main", T_MAIN,},
+      {"exec-program-user", T_EXEC_PROGRAM_USER},
+      {""}, {""}, {""},
+      {"compare-attribute-flag", T_COMPARE_ATTRIBUTE_FLAG},
       {"print-cons", T_LOGOPT, _Y(LO_CONS)},
       {"strip-names", T_STRIP_NAMES},
       {""},
-      {"acl", T_ACL},
-      {"usr2delay", T_USR2DELAY},
+      {"category", T_CATEGORY,},
       {""}, {""}, {""}, {""},
-      {"auth", T_AUTH,},
-      {""},
+      {"access-denied", T_MESGDEF, _Y(MSG_ACCESS_DENIED)},
       {"local7", T_FACILITY, _Y(LOG_LOCAL7)},
       {"second-login", T_MESGDEF, _Y(MSG_SECOND_LOGIN)},
+      {""}, {""}, {""},
+      {"password-expired", T_MESGDEF, _Y(MSG_PASSWORD_EXPIRED)},
       {""},
+      {"password-expire-warning", T_EXPWARNING},
+      {""}, {""},
+      {"local6", T_FACILITY, _Y(LOG_LOCAL6)},
+      {""}, {""},
       {"snmp", T_SNMP},
       {"spawn", T_SPAWN},
-      {""}, {""},
-      {"access-denied", T_MESGDEF, _Y(MSG_ACCESS_DENIED)},
       {"print-priority", T_LOGOPT, _Y(LO_PRI)},
-      {"print-auth", T_LOGLEVEL, _Y(RLOG_AUTH)},
-      {"local4", T_FACILITY, _Y(LOG_LOCAL4)},
-      {""}, {""}, {""}, {""},
-      {"print-level", T_LOGOPT, _Y(LO_PRI),},
       {"warning", T_SEVERITY, _Y(L_WARN)},
-      {"category", T_CATEGORY,},
-      {"username-chars", T_USERNAME_CHARS},
       {""},
-      {"local0", T_FACILITY, _Y(LOG_LOCAL0)},
-      {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
-      {"local2", T_FACILITY, _Y(LOG_LOCAL2)},
-      {""}, {""},
       {"read_only", T_SNMP_ACCESS, _Y(SNMP_RO)},
-      {""}, {""}, {""}, {""}, {""}, {""}, {""},
-      {"logging", T_LOGGING, },
+      {""}, {""}, {""}, {""}, {""},
+      {"print-auth", T_LOGLEVEL, _Y(RLOG_AUTH)},
+      {"print-level", T_LOGOPT, _Y(LO_PRI),},
       {""},
-      {"load-path", T_LOAD_PATH,},
-      {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
+      {"exec-program-group", T_EXEC_PROGRAM_GROUP},
+      {"usr2delay", T_USR2DELAY},
+      {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
+      {"aceclientip", T_ACECLIENTIP},
+      {"main", T_MAIN,},
       {""}, {""},
+      {"logging", T_LOGGING, },
       {"request-cleanup-delay", T_REQUEST_CLEANUP_DELAY},
       {""}, {""}, {""}, {""}, {""}, {""}, {""},
       {"print-category", T_LOGOPT, _Y(LO_CAT)},
-      {""}, {""}, {""},
-      {"timespan-violation", T_MESGDEF, _Y(MSG_TIMESPAN_VIOLATION)},
-      {""}, {""}, {""},
-      {"on", T_BOOL, _Y(1)},
-      {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
       {""}, {""},
-      {"multiple-login", T_MESGDEF, _Y(MSG_MULTIPLE_LOGIN)},
+      {"auth", T_AUTH,},
       {""},
       {"notify", T_NOTIFY},
       {""}, {""},
+      {"load-path", T_LOAD_PATH,},
+      {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
+      {""}, {""},
+      {"usedbm", T_USEDBM},
+      {"on", T_BOOL, _Y(1)},
+      {""}, {""}, {""}, {""}, {""}, {""}, {""},
+      {"timespan-violation", T_MESGDEF, _Y(MSG_TIMESPAN_VIOLATION)},
       {"cntl", T_CNTL},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
-      {"account-closed", T_MESGDEF, _Y(MSG_ACCOUNT_CLOSED)},
+      {"community", T_COMMUNITY},
       {""},
+      {"account-closed", T_MESGDEF, _Y(MSG_ACCOUNT_CLOSED)},
+      {""}, {""}, {""}, {""}, {""}, {""}, {""},
       {"daemon", T_FACILITY, _Y(LOG_DAEMON),},
+      {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
+      {"listen", T_LISTEN,},
       {""}, {""}, {""}, {""},
       {"option", T_OPTION},
+      {""}, {""},
+      {"channel", T_CHANNEL},
       {""}, {""}, {""}, {""},
-      {"listen", T_LISTEN,},
-      {""}, {""},
-      {"community", T_COMMUNITY},
-      {""}, {""},
+      {"username-chars", T_USERNAME_CHARS},
+      {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
+      {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
+      {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
+      {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
+      {""}, {""}, {""},
       {"checkrad-assume-logged", T_CHECKRAD_ASSUME_LOGGED},
-      {""}, {""}, {""}, {""},
-      {"channel", T_CHANNEL}
+      {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
+      {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
+      {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
+      {""}, {""},
+      {"multiple-login", T_MESGDEF, _Y(MSG_MULTIPLE_LOGIN)}
     };
 
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
