@@ -1,23 +1,21 @@
 /* This file is part of GNU RADIUS.
- * Copyright (C) 2001 Sergey Poznyakoff
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *
- */
+   Copyright (C) 2001 Sergey Poznyakoff
+  
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
+  
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+  
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
-#define RADIUS_MODULE 11
+#define RADIUS_MODULE_PAM_C
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -26,7 +24,7 @@
 #ifdef USE_PAM
 
 #ifndef lint
-static char rcsid[] = "@(#) $Id: pam.c,v 1.7 2001/03/14 19:09:26 gray Exp $";
+static char rcsid[] = "@(#) $Id: pam.c,v 1.9 2001/11/27 12:13:36 gray Exp $";
 #endif
 
 #include <sys/types.h>
