@@ -19,7 +19,7 @@
 
 #ifndef lint
 static char rcsid[] =
-"@(#) $Id: radiusd.c,v 1.55.2.1 2002/03/19 15:30:53 gray Exp $";
+"@(#) $Id: radiusd.c,v 1.55.2.5 2002/08/16 12:31:27 gray Exp $";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -66,17 +66,17 @@ typedef struct request {
 
 void rad_req_free(RADIUS_REQ *req);
 void rad_req_drop(int type, RADIUS_REQ *ptr, char *status_str);
-int radreq_cmp(RADIUS_REQ *a, RADIUS_REQ *b);
+int rad_req_cmp(RADIUS_REQ *a, RADIUS_REQ *b);
 
 struct request_class request_class[] = {
 	{ "AUTH", 0, MAX_REQUEST_TIME, CLEANUP_DELAY, 1,
-	  rad_authenticate, NULL, radreq_cmp, rad_req_free,
+	  rad_authenticate, NULL, rad_req_cmp, rad_req_free,
 	  rad_req_drop, rad_sql_setup, rad_sql_cleanup },
 	{ "ACCT", 0, MAX_REQUEST_TIME, CLEANUP_DELAY, 1,
-	  rad_accounting, rad_acct_xmit, radreq_cmp, rad_req_free,
+	  rad_accounting, rad_acct_xmit, rad_req_cmp, rad_req_free,
 	  rad_req_drop, rad_sql_setup, rad_sql_cleanup },
 	{ "PROXY",0, MAX_REQUEST_TIME, CLEANUP_DELAY, 0,
-	  rad_proxy, NULL, radreq_cmp, rad_req_free,
+	  rad_proxy, NULL, rad_req_cmp, rad_req_free,
 	  rad_req_drop, NULL, NULL },
 #ifdef USE_SNMP
 	{ "SNMP", 0, MAX_REQUEST_TIME, 0, 1,
@@ -149,6 +149,7 @@ int        log_mode;
 static int foreground; /* Stay in the foreground */
 static int spawn_flag; 
 int use_dbm = 0;
+int ace_client_ip = 0;
 int open_acct = 1;
 int auth_detail = 0;
 int acct_detail = 1;      
@@ -158,6 +159,11 @@ int suspend_flag;
 serv_stat saved_status;
 #endif
 
+/* These are the user flags marking attributes that
+   can be used in comparing ... */
+int auth_comp_flag; /* ... authentication requests */
+int acct_comp_flag; /* ... accounting requests */
+
 Config config = {
 	10,              /* delayed_hup_wait */
 	1,               /* checkrad_assume_logged */
@@ -1436,13 +1442,97 @@ stat_request_list(stat)
 }
 
 /* ************************************************************************* */
-int
-radreq_cmp(a, b)
-	RADIUS_REQ *a, *b;
+
+VALUE_PAIR *
+rad_req_recode(req, prop)
+	RADIUS_REQ *req;
+	int prop;
 {
-	return !(a->ipaddr == b->ipaddr &&
-		 a->id == b->id &&
-			memcmp(a->vector, b->vector, sizeof(a->vector)) == 0);
+	static int attrlist[] = { DA_PASSWORD, DA_CHAP_PASSWORD };
+	int i;
+	VALUE_PAIR *newlist = NULL;
+	VALUE_PAIR *pair;
+	char password[AUTH_STRING_LEN+1];
+
+	for (pair = req->request; pair; pair = pair->next) 
+		for (i = 0; i < NITEMS(attrlist); i++) {
+			if (pair->attribute == attrlist[i]
+			    && (pair->prop & prop))
+				break;
+		}
+
+	if (!pair)
+		return NULL;
+
+	newlist = avl_dup(req->request);
+	for (pair = newlist; pair; pair = pair->next) 
+		for (i = 0; i < NITEMS(attrlist); i++) {
+			if (pair->attribute == attrlist[i]
+			    && (pair->prop & prop)) {
+				req_decrypt_password(password, req, pair);
+				free_string(pair->strvalue);
+				pair->strvalue = make_string(password);
+				pair->strlength = strlen(pair->strvalue);
+			}
+		}
+	return newlist;
+}
+
+int
+rad_req_cmp(a, b)
+        RADIUS_REQ *a, *b;
+{
+	int prop = 0;
+	VALUE_PAIR *alist = NULL, *blist = NULL, *ap, *bp;
+	int rc;
+	NAS *nas;
+	
+	if (a->ipaddr != b->ipaddr || a->code != b->code)
+		return 1;
+	
+	if (a->id == b->id
+	    && memcmp(a->vector, b->vector, sizeof(a->vector)) == 0)
+		return 0;
+
+	nas = nas_request_to_nas(a);
+
+	if (!prop) {
+		switch (a->code) {
+		case RT_AUTHENTICATION_REQUEST:
+		case RT_AUTHENTICATION_ACK:
+		case RT_AUTHENTICATION_REJECT:
+		case RT_ACCESS_CHALLENGE:
+			prop = envar_lookup_int(nas ? nas->args : NULL,
+						"compare-auth-flag",
+						auth_comp_flag); 
+			break;
+			
+		case RT_ACCOUNTING_REQUEST:
+		case RT_ACCOUNTING_RESPONSE:
+		case RT_ACCOUNTING_STATUS:
+		case RT_ACCOUNTING_MESSAGE:
+			prop = envar_lookup_int(nas ? nas->args : NULL,
+						"compare-acct-flag",
+						acct_comp_flag); 
+			break;
+		}
+	}
+
+	if (prop == 0) 
+		return 1;
+
+	prop |= AP_REQ_CMP;
+	alist = rad_req_recode(a, prop);
+	blist = rad_req_recode(b, prop);
+
+	ap = alist ? alist : a->request;
+	bp = blist ? blist : b->request;
+	
+	rc = avl_cmp(ap, bp, prop) || avl_cmp(bp, ap, prop);
+
+	avl_free(alist);
+	avl_free(blist);
+	return rc;
 }
 
 void
