@@ -18,7 +18,7 @@
 #define RADIUS_MODULE_SQL_C
 #ifndef lint
 static char rcsid[] =
-"@(#) $Id: sql.c,v 1.29.2.1 2002/03/19 16:11:44 gray Exp $";
+"@(#) $Id: sql.c,v 1.29.2.2 2002/07/09 11:39:58 gray Exp $";
 #endif
 
 #if defined(HAVE_CONFIG_H)
@@ -1267,7 +1267,8 @@ rad_sql_retrieve_pairs(conn, query, return_pairs, op_too)
 		chop(attribute);
 		chop(value);
 		
-		pair = install_pair(attribute, op, value);
+		pair = install_pair0("rad_sql_retrieve_pairs", __LINE__,
+                                     attribute, op, value);
 		
                 if (pair) {
 			avl_merge(return_pairs, &pair);
