@@ -15,7 +15,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
-/* $Id: version.c,v 1.16.2.1 2002/06/05 11:40:45 gray Exp $ */
+/* $Id: version.c,v 1.16.2.2 2002/07/31 11:53:58 gray Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -85,6 +85,12 @@ static char *compile_flag_str[] = {
 #if defined(USE_PAM)
 	"USE_PAM",
 #endif
+#if defined(USE_SECURID)
+	"USE_SECURID",
+#endif
+#if defined(USE_SECURID_LEGACY)
+	"USE_SECURID_LEGACY",
+#endif
 #if defined(USE_DBM)
 # if USE_DBM == DBM_DBM	
 	"USE_DBM=DBM",
@@ -101,6 +107,9 @@ static char *compile_flag_str[] = {
 #ifdef USE_SQL_ODBC
 	"USE_SQL_ODBC",
 #endif	
+#ifdef USE_SQL_SYBASE
+	"USE_SQL_SYBASE",
+#endif	
 #if defined(USE_SNMP)
 	"USE_SNMP",
 #endif
