@@ -17,7 +17,7 @@
 
 #ifndef lint
 static char rcsid[] = 
-"$Id: avl.c,v 1.7.2.1 2002/03/19 16:11:58 gray Exp $";
+"$Id: avl.c,v 1.7.2.4 2002/08/05 13:40:32 gray Exp $";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -161,6 +161,31 @@ avp_move(first, new)
 	return new;
 }
 
+int
+avp_cmp(a, b)
+	VALUE_PAIR *a, *b;
+{
+	int rc = 1;
+	
+	if (a->attribute != b->attribute || a->type != b->type)
+		return 1;
+	
+	switch (a->type) {
+	case TYPE_STRING:
+		if (a->strlength != b->strlength)
+			rc = 1;
+		else
+			rc = memcmp(a->strvalue, b->strvalue, a->strlength);
+		break;
+
+	case TYPE_INTEGER:
+	case TYPE_IPADDR:
+		rc = a->lvalue != b->lvalue;
+		break;
+	}
+	return rc;
+}
+
 /* A/V pairlist functions */
 
 /* Release the memory used by a list of attribute-value pairs.
@@ -191,6 +216,19 @@ avl_find(first, attr)
 	return first;
 }
 
+VALUE_PAIR * 
+avl_find_n(first, attr, n)
+	VALUE_PAIR *first; 
+	int attr;
+	int n;
+{
+	for ( ; first; first = first->next) {
+		if (first->attribute == attr && n-- == 0)
+			break;
+	}
+	return first;
+}
+
 /* Delete the pairs with the matching attribute
  */
 void 
@@ -213,6 +251,29 @@ avl_delete(first, attr)
 	}
 }
 
+/* Delete Nth matching pair */
+void 
+avl_delete_n(first, attr, n)
+	VALUE_PAIR **first; 
+	int attr;
+	int n;
+{
+	VALUE_PAIR *pair, *next, *last = NULL;
+
+	for (pair = *first; pair; pair = next) {
+		next = pair->next;
+		if (pair->attribute == attr && n-- == 0) {
+			if (last)
+				last->next = next;
+			else
+				*first = next;
+			avp_free(pair);
+			break;
+		} else
+			last = pair;
+	}
+}
+
 /* Move all attributes of a given type from one list to another */
 void
 avl_move_pairs(to, from, fun, closure)
@@ -377,3 +438,22 @@ avl_fprint(fp, avl)
 		fprintf(fp, "    %s\n", format_pair(avl));
 }
 
+
+int
+avl_cmp(a, b, prop)
+	VALUE_PAIR *a, *b;
+	int prop;
+{
+	int cmp_count = 0;
+	
+	for (; a; a = a->next) {
+		if (a->prop & prop) {
+			VALUE_PAIR *p = avl_find(b, a->attribute);
+			if (!p || avp_cmp(a, p))
+				return 1;
+			cmp_count++;
+		}
+	}
+	return cmp_count == 0;
+}
+
