@@ -37,7 +37,7 @@
 
 #ifndef lint
 static char rcsid[] = 
-"$Id: users.y,v 1.17.2.1 2002/05/30 14:02:50 gray Exp $";
+"$Id: users.y,v 1.17.2.2 2002/07/09 11:40:48 gray Exp $";
 #endif
 
 #if defined(HAVE_CONFIG_H)
@@ -71,7 +71,7 @@ int old_lineno;
 static void *closure;
 static int (*add_entry)(void*, char *, int, char *, VALUE_PAIR *, VALUE_PAIR *);
 
-VALUE_PAIR *install_pair(char *name, int op, char *valstr);
+static VALUE_PAIR *install_pair(char *name, int op, char *valstr);
 
 #line 69 "users.y"
 typedef union {
@@ -83,6 +83,10 @@ typedef union {
 	VALUE_PAIR *pair;
 	int op;
 } YYSTYPE;
+#ifndef YYDEBUG
+#define YYDEBUG 1
+#endif
+
 #include <stdio.h>
 
 #ifndef __cplusplus
@@ -1091,6 +1095,18 @@ uyyerror(s)
 
 VALUE_PAIR *
 install_pair(name, op, valstr)
+        char *name;
+        int op;
+        char *valstr;
+{
+	return install_pair0(source_filename, source_line_num, 
+                             name, op, valstr);
+}
+
+VALUE_PAIR *
+install_pair0(filename, line, name, op, valstr)
+	char *filename;
+	int line;
 	char *name;
 	int op;
 	char *valstr;
@@ -1105,7 +1121,7 @@ install_pair(name, op, valstr)
 	
 	if ((attr = attr_name_to_dict(name)) == (DICT_ATTR *)NULL) {
 		radlog(L_ERR, _("%s:%d: unknown attribute `%s'"),
-		       source_filename, source_line_num, name);
+		       filename, line, name);
 		return NULL;
 	}
 
@@ -1134,7 +1150,7 @@ install_pair(name, op, valstr)
 			if (valstr[0] != '/') {
 				radlog(L_ERR,
 				   _("%s:%d: %s: not an absolute pathname"),
-				       source_filename, source_line_num, name);
+				       filename, line, name);
 				avp_free(pair);
 				return NULL;
 			}
@@ -1145,7 +1161,7 @@ install_pair(name, op, valstr)
 
 		if (attr->parser && attr->parser(pair, &s)) {
 			radlog(L_ERR, "%s:%d: attribute %s: %s",
-			       source_filename, source_line_num,
+			       filename, line,
 			       pair->name, s);
 			free(s);
 			avp_free(pair);
@@ -1172,10 +1188,9 @@ install_pair(name, op, valstr)
 		if (isdigit(*valstr)) {
 			pair->lvalue = atoi(valstr);
 		} else if ((dval = value_name_to_value(valstr, pair->attribute)) == NULL) {
+			radlog(L_ERR, _("%s:%d: value %s is not declared for attribute %s"),
+			       filename, line, valstr, name);
 			avp_free(pair);
-			radlog(L_ERR, _("%s:%d: unknown value %s"),
-			    source_filename, source_line_num,
-			    valstr);
 			return NULL;
 		} else {
 			pair->lvalue = dval->value;
@@ -1222,7 +1237,7 @@ install_pair(name, op, valstr)
 		if (user_gettime(valstr, tm)) {
 			radlog(L_ERR,
 				_("%s:%d: %s: can't parse date"),
-				source_filename, source_line_num, name);
+				filename, line, name);
 			avp_free(pair);
 			return NULL;
 		}
@@ -1235,7 +1250,7 @@ install_pair(name, op, valstr)
 
 	default:
 		radlog(L_ERR, _("%s:%d: %s: unknown attribute type %d"),
-		    source_filename, source_line_num, name,
+		    filename, line, name,
 		    pair->type);
 		avp_free(pair);
 		return NULL;
