@@ -49,7 +49,7 @@
         
 #ifndef lint    
 static char rcsid[] = 
-        "@(#) $Id: gram.y,v 1.9 2001/12/18 14:22:55 gray Exp $";
+        "@(#) $Id: gram.y,v 1.9.2.1 2002/07/09 11:40:10 gray Exp $";
 #endif  
 #if defined(HAVE_CONFIG_H)        
 # include <config.h>
@@ -178,9 +178,9 @@ static const short yyrhs[] = {    -1,
 static const short yyrline[] = { 0,
     93,    94,    96,   100,   106,   107,   111,   124,   129,   157,
    162,   168,   172,   178,   179,   190,   191,   204,   208,   215,
-   221,   225,   236,   247,   254,   261,   262,   263,   269,   273,
-   281,   285,   289,   293,   297,   301,   307,   313,   319,   325,
-   329,   334,   339,   347,   348,   351
+   221,   225,   236,   247,   254,   262,   263,   264,   270,   274,
+   282,   286,   290,   294,   298,   302,   308,   314,   320,   326,
+   330,   335,   340,   348,   349,   352
 };
 #endif
 
@@ -993,12 +993,13 @@ case 24:
 case 25:
 #line 255 "gram.y"
 {
-                        yyval.pair = install_pair(yyvsp[-2].string, yyvsp[-1].number, yyvsp[0].string);
+                        yyval.pair = install_pair0(source_filename, source_line_num,
+                                           yyvsp[-2].string, yyvsp[-1].number, yyvsp[0].string);
 			free_string(yyvsp[0].string);
                 ;
     break;}
 case 28:
-#line 264 "gram.y"
+#line 265 "gram.y"
 {
                         char buf[64];
                         sprintf(buf, "%d", yyvsp[0].number);
@@ -1006,13 +1007,13 @@ case 28:
                 ;
     break;}
 case 29:
-#line 270 "gram.y"
+#line 271 "gram.y"
 {
                         yyval.string = print_ident(yyvsp[0].ident);
                 ;
     break;}
 case 30:
-#line 274 "gram.y"
+#line 275 "gram.y"
 {
                         char buf[DOTTED_QUAD_LEN];
                         ipaddr2str(buf, yyvsp[0].ipaddr);
@@ -1020,43 +1021,43 @@ case 30:
                 ;
     break;}
 case 31:
-#line 282 "gram.y"
+#line 283 "gram.y"
 {
                         yyval.number = OPERATOR_EQUAL;
                 ;
     break;}
 case 32:
-#line 286 "gram.y"
+#line 287 "gram.y"
 {
                         yyval.number = OPERATOR_LESS_THAN;
                 ;
     break;}
 case 33:
-#line 290 "gram.y"
+#line 291 "gram.y"
 { 
                         yyval.number = OPERATOR_GREATER_THAN;
                 ;
     break;}
 case 34:
-#line 294 "gram.y"
+#line 295 "gram.y"
 {
                         yyval.number = OPERATOR_NOT_EQUAL;
                 ;
     break;}
 case 35:
-#line 298 "gram.y"
+#line 299 "gram.y"
 {
                         yyval.number = OPERATOR_LESS_EQUAL;
                 ;
     break;}
 case 36:
-#line 302 "gram.y"
+#line 303 "gram.y"
 {
                         yyval.number = OPERATOR_GREATER_EQUAL;
                 ;
     break;}
 case 37:
-#line 308 "gram.y"
+#line 309 "gram.y"
 {
 			yyval.variable.name = NULL;
                         yyval.variable.type = Integer;
@@ -1064,7 +1065,7 @@ case 37:
                 ;
     break;}
 case 38:
-#line 314 "gram.y"
+#line 315 "gram.y"
 {
 			yyval.variable.name = NULL;
                         yyval.variable.type = Ipaddress;
@@ -1072,7 +1073,7 @@ case 38:
                 ;
     break;}
 case 39:
-#line 320 "gram.y"
+#line 321 "gram.y"
 {
 			yyval.variable.name = NULL;
                         yyval.variable.type = String;
@@ -1080,27 +1081,27 @@ case 39:
                 ;
     break;}
 case 40:
-#line 326 "gram.y"
+#line 327 "gram.y"
 {
                         yyval.variable = *yyvsp[0].ident;
                 ;
     break;}
 case 41:
-#line 330 "gram.y"
+#line 331 "gram.y"
 {
 			yyval.variable.name = NULL;
                         subscript(yyvsp[-3].ident, yyvsp[-1].string, 0, &yyval.variable);
                 ;
     break;}
 case 42:
-#line 335 "gram.y"
+#line 336 "gram.y"
 {
 			yyval.variable.name = NULL;
                         subscript(yyvsp[-4].ident, yyvsp[-2].string, 1, &yyval.variable);
                 ;
     break;}
 case 43:
-#line 340 "gram.y"
+#line 341 "gram.y"
 {
 			yyval.variable.name = NULL;
                         yyval.variable.type = Vector;
@@ -1108,7 +1109,7 @@ case 43:
                 ;
     break;}
 case 46:
-#line 352 "gram.y"
+#line 353 "gram.y"
 {
                         var_print(&yyvsp[0].variable);
 			var_free(&yyvsp[0].variable);
@@ -1336,7 +1337,7 @@ yyerrhandle:
     }
   return 1;
 }
-#line 358 "gram.y"
+#line 359 "gram.y"
 
 
 yyerror(s)
