@@ -17,7 +17,7 @@
 
 #ifndef lint
 static char rcsid[] = 
-	"@(#) $Id: main.c,v 1.12 2001/12/19 14:05:44 gray Exp $";
+	"@(#) $Id: main.c,v 1.12.2.1 2002/08/14 14:31:59 gray Exp $";
 #endif
 #if defined(HAVE_CONFIG_H)        
 # include <config.h>
@@ -244,9 +244,9 @@ main(argc, argv)
 	argc -= optind;
 	argv += optind;
 
-	x_argv = emalloc(sizeof(x_argv[0]) * argc);
+	x_argmax = argc + 2; 
+	x_argv = emalloc(sizeof(x_argv[0]) * x_argmax);
 	x_argc = 0;
-	x_argmax = argc;
 	x_argv[x_argc++] = filename;
 
 	for (; argc; argc--, argv++) {
